@@ -83,10 +83,11 @@ class Gamess:
         # merged into this options set
         self._options = {
             'contrl': {'scftyp': 'rhf', 'runtyp': 'energy', 'maxit': 200},
-            'basis': {'gbasis': 'sto', 'ngauss': '3'},
-            'statpt': {'opttol': '0.0001', 'nstep': '20'},
-            'system': {'mwords': '100', 'memddi': '0'},
-            'cis': {'nstate': '1'}
+            'basis': {'gbasis': 'sto', 'ngauss': 3},
+            'statpt': {'opttol': '0.0001', 'nstep': 100},
+            'system': {'mwords': 300, 'memddi': 0},
+            'scf': {'dirscf': '.f.'},
+            'cis': {'nstate': 1}
         }
 
         self._options.update(options)
@@ -154,7 +155,16 @@ class Gamess:
         nmol.SetDoubleProp("dx", result.dipole_moment[0])
         nmol.SetDoubleProp("dy", result.dipole_moment[1])
         nmol.SetDoubleProp("dz", result.dipole_moment[2])
-        nmol.SetProp("orbital_energies", " ".join([str(v) for v in result.orbital_energies]))
+        nmol.SetProp("orbital_energies", str(result.orbital_energies))
+        nmol.SetProp("program", "GAMESS")
+        nmol.SetProp("basis", str(self._options['basis']))
+        nmol.SetProp("method", str(self._options['contrl']))
+        if hasattr(result, "uv_spectra"):
+            nmol.SetProp("uv_spectra", str(result.uv_spectra))
+        if hasattr(result, "isotropic_shielding"):
+            nmol.SetProp("isotropic_shielding", str(result.isotropic_shielding))
+        if hasattr(result, "ir_spectra"):
+            nmol.SetProp("ir_spectra", str(result.ir_spectra))
 
         for i, cds in enumerate(result.coordinates):
             conf.SetAtomPosition(i, cds)
@@ -195,10 +205,11 @@ class Gamess:
         """ gamess header"""
         # self.contrl['icharg'] = mol.GetFormalCharge()
         # TODO: cope with the charge and the multiplicity of the compound
-        header = "{}{}{}{}".format(
+        header = "{}{}{}{}{}".format(
             self.print_section('contrl'),
             self.print_section('pcm'),
             self.print_section('basis'),
+            self.print_section('scf'),
             self.print_section('system'))
 
         if self._options['contrl']['runtyp'] == 'optimize':
@@ -207,6 +218,9 @@ class Gamess:
         if self._options['contrl'].get('citype', None) == 'cis':
             header += self.print_section('cis')
 
+        if self._options['contrl'].get('tddft', None) == 'excite':
+            header += self.print_section('tddft')
+
         return header
 
     def print_section(self, pref):
@@ -216,9 +230,11 @@ class Gamess:
             ret_flag = True
             d = self._options[pref]
             section = " ${} ".format(pref)
+            num_items = len(d)
             for k, v in d.items():
                 section += "{}={} ".format(k, v)
-                if ret_flag and len(section) > 60:
+                num_items -= 1
+                if ret_flag and len(section) > 60 and num_items > 0:
                     section += "\n"
                     ret_flag = False
             section += "$end\n"
@@ -275,12 +291,25 @@ class Gamess:
             logger.error("basis type not found")
         logger.info(self._options['basis'])
 
-    def run_type(self, runtype):
+    def run_type(self, runtype, hessend=False):
         self._options['contrl']['runtyp'] = runtype
+        if runtype == "optimize":
+            self.hessend(hessend)
         logger.debug(self._options['contrl'])
 
-    def dft_type(self, dfttype):
+    def dft_type(self, dfttype, tddft=False, nstate=10):
         self._options['contrl']['dfttyp'] = dfttype
+        if tddft:
+            self._options['contrl']['tddft'] = "excite"
+            if "tddft" not in self._options:
+                self._options['tddft'] = {}
+            self._options['tddft']['nstate'] = nstate
+        else:
+            self._options['contrl'].pop('tddft', None)
+        logger.debug(self._options['contrl'])
+
+    def ci_type(self, citype):
+        self._options['contrl']['cityp'] = citype
         logger.debug(self._options['contrl'])
 
     def scf_type(self, scftype):
@@ -299,6 +328,17 @@ class Gamess:
         self._options['contrl']['mult'] = mult
         logger.debug(self._options['contrl'])
 
+    def hessend(self, hessend):
+        if hessend:
+            self._options['statpt']['hssend'] = ".t."
+            self._options['contrl']['nosym'] = 1
+            self._options['scf']['dirscf'] = ".t."
+        else:
+            self._options['statpt']['hssend'] = ".f."
+            self._options['contrl'].pop('nosym', None)
+            self._options['scf']['dirscf'] = ".f."
+        logger.debug(self._options['statpt'])
+
     def pcm_type(self, solvent, ief=-10):
         """C-PCM is normally a better choice than IEF-PCM.  The                            
         iterative solvers chosen by IEF=-3 or -10 usually reproduce                     
@@ -320,6 +360,7 @@ class Gamess:
     def options(self, options):
         for k, v in options.items():
             self._options[k].update(v)
+        logger.debug(self._options)
 
     def exec_rungms(self, mol):
         self.gamin = self.write_file(mol)
